@@ -42,12 +42,6 @@ class Build_Mode(enum.Enum):
    DISABLED = "disabled"
    REBUILD = "rebuild"
 
-# ch-run exit codes (see also: bin/ch_misc.h)
-class Ch_Run_Retcode(enum.Enum):
-   EXIT_MISC_ERR = 31
-   EXIT_CMD = 49
-   EXIT_SQUASH = 84
-
 # Download cache mode.
 class Download_Mode(enum.Enum):
    ENABLED = "enabled"
@@ -76,6 +70,13 @@ class Log_Level(enum.Enum):
          return self.value < other.value
       return NotImplemented
 
+# ch-run exit codes (see also: bin/ch_misc.h)
+class Run_Exit(enum.Enum):
+   OK = 0
+   ERR_MISC = 31
+   ERR_CMD = 49
+   ERR_SQUASH = 84
+
 
 ## Constants ##
 
@@ -577,20 +578,7 @@ def cmd_base(argv, fail_ok=False, **kwargs):
          kwargs["stderr"] = subprocess.PIPE
    if ("input" not in kwargs):
       kwargs["stdin"] = subprocess.DEVNULL
-   try:
-      profile_stop()
-      cp = subprocess.run(argv, **kwargs)
-      profile_start()
-   except OSError as x:
-      VERBOSE("can’t execute %s: %s" % (argv[0], x.strerror))
-      # Most common reason we are here is that the command isn’t found, which
-      # generates a FileNotFoundError. Use fake return value 127; this is
-      # consistent with the shell [1]. This is a kludge, but we assume the
-      # caller doesn’t care about the distinction between some problem within
-      # the subprocess and inability to start the subprocess.
-      #
-      # [1]: https://devdocs.io/bash/exit-status#Exit-Status
-      cp = subprocess.CompletedProcess(argv, 127)
+   cp = cmd_simple(argv, **kwargs)
    if (not fail_ok and cp.returncode != 0):
       if (cp.stderr is not None):
          if (isinstance(cp.stderr, bytes)):
@@ -610,6 +598,25 @@ def cmd_quiet(argv, **kwargs):
       stdout=subprocess.DEVNULL
    return cmd(argv, stdout=stdout, **kwargs)
 
+def cmd_simple(argv, **kwargs):
+   """Run a command and return its subprocess.CompletedProcess instance. If it
+      couldn’t be started, log that and return a fake CompletedProcess."""
+   try:
+      profile_stop()
+      cp = subprocess.run(argv, **kwargs)
+      profile_start()
+   except OSError as x:
+      VERBOSE("can’t execute %s: %s" % (argv[0], x.strerror))
+      # Most common reason we are here is that the command isn’t found, which
+      # generates a FileNotFoundError. Use fake return value 127; this is
+      # consistent with the shell [1]. This is a kludge, but we assume the
+      # caller doesn’t care about the distinction between some problem within
+      # the subprocess and inability to start the subprocess.
+      #
+      # [1]: https://devdocs.io/bash/exit-status#Exit-Status
+      cp = subprocess.CompletedProcess(argv, 127)
+   return cp
+
 def cmd_stdout(argv, encoding="UTF-8", **kwargs):
    """Run command using cmd_base(), capturing its standard output. Return the
       CompletedProcess object (its stdout is available in the “stdout”
